Package: scTGIF
Type: Package
Title: Cell type annotation for unannotated single-cell RNA-Seq data
Version: 1.25.0
Authors@R: person("Koki", "Tsuyuzaki", role = c("aut", "cre"),
    email = "k.t.the-answer@hotmail.co.jp")
Depends: R (>= 3.6.0)
Imports: GSEABase, Biobase, SingleCellExperiment, BiocStyle, plotly,
        tagcloud, rmarkdown, Rcpp, grDevices, graphics, utils, knitr,
        S4Vectors, SummarizedExperiment, RColorBrewer, nnTensor,
        methods, scales, msigdbr, schex, tibble, ggplot2, igraph
Suggests: testthat
Description: scTGIF connects the cells and the related gene functions without
    cell type label.
License: Artistic-2.0
biocViews: DimensionReduction, QualityControl, SingleCell, Software,
        GeneExpression
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/scTGIF
git_branch: devel
git_last_commit: f7ab3ab
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-11-03
NeedsCompilation: no
Packaged: 2025-11-04 00:51:29 UTC; biocbuild
Author: Koki Tsuyuzaki [aut, cre]
Maintainer: Koki Tsuyuzaki <k.t.the-answer@hotmail.co.jp>
